# coding: utf-8

"""
    RCABench API

    RCABench - A comprehensive root cause analysis benchmarking platform for microservices This API provides endpoints for managing datasets, algorithms, evaluations, and fault injections for root cause analysis in distributed systems and microservices architectures.

    The version of the OpenAPI document: 1.0.1
    Contact: team@rcabench.com
    Generated by OpenAPI Generator (https://rcabench.openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import io
import warnings

from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Dict, List, Optional, Tuple, Union, Any

try:
    from typing import Annotated
except ImportError:
    from typing_extensions import Annotated

from pydantic import Field
from typing_extensions import Annotated
from rcabench.openapi.models.dto_generic_response_dto_list_algorithms_resp import DtoGenericResponseDtoListAlgorithmsResp
from rcabench.openapi.models.dto_generic_response_dto_submit_resp import DtoGenericResponseDtoSubmitResp
from rcabench.openapi.models.dto_submit_execution_req import DtoSubmitExecutionReq

from rcabench.openapi.api_client import ApiClient
from rcabench.openapi.api_response import ApiResponse
from rcabench.openapi.rest import RESTResponseType


class AlgorithmApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://rcabench.openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def api_v1_algorithms_get(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> DtoGenericResponseDtoListAlgorithmsResp:
        """Get algorithm list

        Get all available algorithms in the system, including image info, tags, and update time. Only returns containers with active status.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_algorithms_get_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DtoGenericResponseDtoListAlgorithmsResp",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_algorithms_get_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[DtoGenericResponseDtoListAlgorithmsResp]:
        """Get algorithm list

        Get all available algorithms in the system, including image info, tags, and update time. Only returns containers with active status.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_algorithms_get_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DtoGenericResponseDtoListAlgorithmsResp",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_algorithms_get_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get algorithm list

        Get all available algorithms in the system, including image info, tags, and update time. Only returns containers with active status.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_algorithms_get_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DtoGenericResponseDtoListAlgorithmsResp",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_algorithms_get_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v1/algorithms',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_v1_algorithms_post(
        self,
        body: Annotated[DtoSubmitExecutionReq, Field(description="Algorithm execution request list, including algorithm name, dataset, and environment variables")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> DtoGenericResponseDtoSubmitResp:
        """Submit algorithm execution task

        Batch submit algorithm execution tasks, supporting multiple algorithm and dataset combinations. The system assigns a unique TraceID for each execution task to track status and results.

        :param body: Algorithm execution request list, including algorithm name, dataset, and environment variables (required)
        :type body: DtoSubmitExecutionReq
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_algorithms_post_serialize(
            body=body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "DtoGenericResponseDtoSubmitResp",
            '400': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_v1_algorithms_post_with_http_info(
        self,
        body: Annotated[DtoSubmitExecutionReq, Field(description="Algorithm execution request list, including algorithm name, dataset, and environment variables")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[DtoGenericResponseDtoSubmitResp]:
        """Submit algorithm execution task

        Batch submit algorithm execution tasks, supporting multiple algorithm and dataset combinations. The system assigns a unique TraceID for each execution task to track status and results.

        :param body: Algorithm execution request list, including algorithm name, dataset, and environment variables (required)
        :type body: DtoSubmitExecutionReq
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_algorithms_post_serialize(
            body=body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "DtoGenericResponseDtoSubmitResp",
            '400': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_v1_algorithms_post_without_preload_content(
        self,
        body: Annotated[DtoSubmitExecutionReq, Field(description="Algorithm execution request list, including algorithm name, dataset, and environment variables")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Submit algorithm execution task

        Batch submit algorithm execution tasks, supporting multiple algorithm and dataset combinations. The system assigns a unique TraceID for each execution task to track status and results.

        :param body: Algorithm execution request list, including algorithm name, dataset, and environment variables (required)
        :type body: DtoSubmitExecutionReq
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_v1_algorithms_post_serialize(
            body=body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': "DtoGenericResponseDtoSubmitResp",
            '400': "DtoGenericResponseAny",
            '500': "DtoGenericResponseAny",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_v1_algorithms_post_serialize(
        self,
        body,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if body is not None:
            _body_params = body


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v1/algorithms',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    RCABench API

    RCABench - A comprehensive root cause analysis benchmarking platform for microservices This API provides endpoints for managing datasets, algorithms, evaluations, and fault injections for root cause analysis in distributed systems and microservices architectures.

    The version of the OpenAPI document: 1.0.1
    Contact: team@rcabench.com
    Generated by OpenAPI Generator (https://rcabench.openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictBool, StrictInt
from pydantic import Field
from typing_extensions import Annotated
from rcabench.openapi.models.dto_dataset_v2_label_create_req import DtoDatasetV2LabelCreateReq
from rcabench.openapi.models.dto_injection_ref import DtoInjectionRef
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class DtoDatasetV2UpdateReq(BaseModel):
    """
    DtoDatasetV2UpdateReq
    """ # noqa: E501
    data_source: Optional[Annotated[str, Field(strict=True, max_length=500)]] = Field(default=None, description="Data source description")
    description: Optional[Annotated[str, Field(strict=True, max_length=1000)]] = Field(default=None, description="Dataset description")
    format: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="Data format")
    injection_refs: Optional[List[DtoInjectionRef]] = Field(default=None, description="Update associated fault injection references (complete replacement)")
    is_public: Optional[StrictBool] = Field(default=None, description="Whether public")
    label_ids: Optional[List[StrictInt]] = Field(default=None, description="Update associated label ID list (complete replacement)")
    name: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="Dataset name")
    new_labels: Optional[List[DtoDatasetV2LabelCreateReq]] = Field(default=None, description="New label list")
    type: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="Dataset type")
    version: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="Dataset version")
    __properties: ClassVar[List[str]] = ["data_source", "description", "format", "injection_refs", "is_public", "label_ids", "name", "new_labels", "type", "version"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of DtoDatasetV2UpdateReq from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in injection_refs (list)
        _items = []
        if self.injection_refs:
            for _item in self.injection_refs:
                if _item:
                    _items.append(_item.to_dict())
            _dict['injection_refs'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in new_labels (list)
        _items = []
        if self.new_labels:
            for _item in self.new_labels:
                if _item:
                    _items.append(_item.to_dict())
            _dict['new_labels'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of DtoDatasetV2UpdateReq from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "data_source": obj.get("data_source"),
            "description": obj.get("description"),
            "format": obj.get("format"),
            "injection_refs": [DtoInjectionRef.from_dict(_item) for _item in obj.get("injection_refs")] if obj.get("injection_refs") is not None else None,
            "is_public": obj.get("is_public"),
            "label_ids": obj.get("label_ids"),
            "name": obj.get("name"),
            "new_labels": [DtoDatasetV2LabelCreateReq.from_dict(_item) for _item in obj.get("new_labels")] if obj.get("new_labels") is not None else None,
            "type": obj.get("type"),
            "version": obj.get("version")
        })
        return _obj





# coding: utf-8

"""
    RCABench API

    RCABench - A comprehensive root cause analysis benchmarking platform for microservices This API provides endpoints for managing datasets, algorithms, evaluations, and fault injections for root cause analysis in distributed systems and microservices architectures.

    The version of the OpenAPI document: 1.0.1
    Contact: team@rcabench.com
    Generated by OpenAPI Generator (https://rcabench.openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictBool, StrictInt, StrictStr
from pydantic import Field
from rcabench.openapi.models.database_container import DatabaseContainer
from rcabench.openapi.models.database_dataset import DatabaseDataset
from rcabench.openapi.models.database_label import DatabaseLabel
from rcabench.openapi.models.dto_injection_v2_response import DtoInjectionV2Response
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class DtoProjectV2Response(BaseModel):
    """
    DtoProjectV2Response
    """ # noqa: E501
    containers: Optional[List[DatabaseContainer]] = Field(default=None, description="Associated containers")
    created_at: Optional[StrictStr] = Field(default=None, description="Creation time")
    datasets: Optional[List[DatabaseDataset]] = Field(default=None, description="Associated datasets")
    description: Optional[StrictStr] = Field(default=None, description="Project description")
    id: Optional[StrictInt] = Field(default=None, description="Unique identifier")
    injections: Optional[List[DtoInjectionV2Response]] = Field(default=None, description="Associated fault injections")
    is_public: Optional[StrictBool] = Field(default=None, description="Whether public")
    labels: Optional[List[DatabaseLabel]] = Field(default=None, description="Associated labels")
    name: Optional[StrictStr] = Field(default=None, description="Project name")
    status: Optional[StrictInt] = Field(default=None, description="Status")
    updated_at: Optional[StrictStr] = Field(default=None, description="Update time")
    __properties: ClassVar[List[str]] = ["containers", "created_at", "datasets", "description", "id", "injections", "is_public", "labels", "name", "status", "updated_at"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of DtoProjectV2Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in containers (list)
        _items = []
        if self.containers:
            for _item in self.containers:
                if _item:
                    _items.append(_item.to_dict())
            _dict['containers'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in datasets (list)
        _items = []
        if self.datasets:
            for _item in self.datasets:
                if _item:
                    _items.append(_item.to_dict())
            _dict['datasets'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in injections (list)
        _items = []
        if self.injections:
            for _item in self.injections:
                if _item:
                    _items.append(_item.to_dict())
            _dict['injections'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in labels (list)
        _items = []
        if self.labels:
            for _item in self.labels:
                if _item:
                    _items.append(_item.to_dict())
            _dict['labels'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of DtoProjectV2Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "containers": [DatabaseContainer.from_dict(_item) for _item in obj.get("containers")] if obj.get("containers") is not None else None,
            "created_at": obj.get("created_at"),
            "datasets": [DatabaseDataset.from_dict(_item) for _item in obj.get("datasets")] if obj.get("datasets") is not None else None,
            "description": obj.get("description"),
            "id": obj.get("id"),
            "injections": [DtoInjectionV2Response.from_dict(_item) for _item in obj.get("injections")] if obj.get("injections") is not None else None,
            "is_public": obj.get("is_public"),
            "labels": [DatabaseLabel.from_dict(_item) for _item in obj.get("labels")] if obj.get("labels") is not None else None,
            "name": obj.get("name"),
            "status": obj.get("status"),
            "updated_at": obj.get("updated_at")
        })
        return _obj





# coding: utf-8

"""
    RCABench API

    RCABench - A comprehensive root cause analysis benchmarking platform for microservices This API provides endpoints for managing datasets, algorithms, evaluations, and fault injections for root cause analysis in distributed systems and microservices architectures.

    The version of the OpenAPI document: 1.0.1
    Contact: team@rcabench.com
    Generated by OpenAPI Generator (https://rcabench.openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictBool, StrictInt, StrictStr, field_validator
from pydantic import Field
from rcabench.openapi.models.dto_label_item import DtoLabelItem
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class DtoInjectionV2SearchReq(BaseModel):
    """
    DtoInjectionV2SearchReq
    """ # noqa: E501
    benchmarks: Optional[List[StrictStr]] = None
    created_at_gte: Optional[StrictStr] = None
    created_at_lte: Optional[StrictStr] = None
    end_time_gte: Optional[StrictStr] = None
    end_time_lte: Optional[StrictStr] = None
    fault_types: Optional[List[StrictInt]] = None
    include_labels: Optional[StrictBool] = Field(default=None, description="Whether to include labels in the response")
    include_task: Optional[StrictBool] = Field(default=None, description="Whether to include task details in the response")
    labels: Optional[List[DtoLabelItem]] = Field(default=None, description="Custom labels to filter by")
    page: Optional[StrictInt] = None
    search: Optional[StrictStr] = None
    size: Optional[StrictInt] = None
    sort_by: Optional[StrictStr] = None
    sort_order: Optional[StrictStr] = None
    start_time_gte: Optional[StrictStr] = None
    start_time_lte: Optional[StrictStr] = None
    statuses: Optional[List[StrictInt]] = None
    tags: Optional[List[StrictStr]] = Field(default=None, description="Tag values to filter by")
    task_ids: Optional[List[StrictStr]] = None
    __properties: ClassVar[List[str]] = ["benchmarks", "created_at_gte", "created_at_lte", "end_time_gte", "end_time_lte", "fault_types", "include_labels", "include_task", "labels", "page", "search", "size", "sort_by", "sort_order", "start_time_gte", "start_time_lte", "statuses", "tags", "task_ids"]

    @field_validator('sort_by')
    def sort_by_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('id', 'task_id', 'fault_type', 'status', 'benchmark', 'injection_name', 'created_at', 'updated_at'):
            raise ValueError("must be one of enum values ('id', 'task_id', 'fault_type', 'status', 'benchmark', 'injection_name', 'created_at', 'updated_at')")
        return value

    @field_validator('sort_order')
    def sort_order_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('asc', 'desc'):
            raise ValueError("must be one of enum values ('asc', 'desc')")
        return value

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of DtoInjectionV2SearchReq from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in labels (list)
        _items = []
        if self.labels:
            for _item in self.labels:
                if _item:
                    _items.append(_item.to_dict())
            _dict['labels'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of DtoInjectionV2SearchReq from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "benchmarks": obj.get("benchmarks"),
            "created_at_gte": obj.get("created_at_gte"),
            "created_at_lte": obj.get("created_at_lte"),
            "end_time_gte": obj.get("end_time_gte"),
            "end_time_lte": obj.get("end_time_lte"),
            "fault_types": obj.get("fault_types"),
            "include_labels": obj.get("include_labels"),
            "include_task": obj.get("include_task"),
            "labels": [DtoLabelItem.from_dict(_item) for _item in obj.get("labels")] if obj.get("labels") is not None else None,
            "page": obj.get("page"),
            "search": obj.get("search"),
            "size": obj.get("size"),
            "sort_by": obj.get("sort_by"),
            "sort_order": obj.get("sort_order"),
            "start_time_gte": obj.get("start_time_gte"),
            "start_time_lte": obj.get("start_time_lte"),
            "statuses": obj.get("statuses"),
            "tags": obj.get("tags"),
            "task_ids": obj.get("task_ids")
        })
        return _obj





# coding: utf-8

"""
    RCABench API

    RCABench - A comprehensive root cause analysis benchmarking platform for microservices This API provides endpoints for managing datasets, algorithms, evaluations, and fault injections for root cause analysis in distributed systems and microservices architectures.

    The version of the OpenAPI document: 1.0.1
    Contact: team@rcabench.com
    Generated by OpenAPI Generator (https://rcabench.openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictBool, StrictInt, StrictStr
from pydantic import Field
from typing_extensions import Annotated
from rcabench.openapi.models.dto_date_range import DtoDateRange
from rcabench.openapi.models.dto_search_filter import DtoSearchFilter
from rcabench.openapi.models.dto_sort_option import DtoSortOption
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class DtoUserSearchRequest(BaseModel):
    """
    DtoUserSearchRequest
    """ # noqa: E501
    created_at: Optional[DtoDateRange] = None
    departments: Optional[List[StrictStr]] = Field(default=None, description="Department filter")
    email_pattern: Optional[StrictStr] = Field(default=None, description="Email fuzzy match")
    exclude_fields: Optional[List[StrictStr]] = None
    filters: Optional[List[DtoSearchFilter]] = Field(default=None, description="Filters")
    fullname_pattern: Optional[StrictStr] = Field(default=None, description="Full name fuzzy match")
    include: Optional[List[StrictStr]] = Field(default=None, description="Include related entities")
    include_fields: Optional[List[StrictStr]] = Field(default=None, description="Include/Exclude fields")
    is_active: Optional[StrictBool] = None
    keyword: Optional[StrictStr] = Field(default=None, description="Search keyword (for general text search)")
    last_login_range: Optional[DtoDateRange] = None
    page: Optional[Annotated[int, Field(strict=True, ge=1)]] = Field(default=None, description="Pagination")
    project_id: Optional[StrictInt] = None
    project_ids: Optional[List[StrictInt]] = Field(default=None, description="Project ID filter")
    role_ids: Optional[List[StrictInt]] = Field(default=None, description="Role ID filter")
    size: Optional[Annotated[int, Field(le=1000, strict=True, ge=1)]] = None
    sort: Optional[List[DtoSortOption]] = Field(default=None, description="Sort")
    status: Optional[List[StrictInt]] = None
    updated_at: Optional[DtoDateRange] = None
    user_id: Optional[StrictInt] = None
    username_pattern: Optional[StrictStr] = Field(default=None, description="User-specific filter shortcuts")
    __properties: ClassVar[List[str]] = ["created_at", "departments", "email_pattern", "exclude_fields", "filters", "fullname_pattern", "include", "include_fields", "is_active", "keyword", "last_login_range", "page", "project_id", "project_ids", "role_ids", "size", "sort", "status", "updated_at", "user_id", "username_pattern"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of DtoUserSearchRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of created_at
        if self.created_at:
            _dict['created_at'] = self.created_at.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in filters (list)
        _items = []
        if self.filters:
            for _item in self.filters:
                if _item:
                    _items.append(_item.to_dict())
            _dict['filters'] = _items
        # override the default output from pydantic by calling `to_dict()` of last_login_range
        if self.last_login_range:
            _dict['last_login_range'] = self.last_login_range.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in sort (list)
        _items = []
        if self.sort:
            for _item in self.sort:
                if _item:
                    _items.append(_item.to_dict())
            _dict['sort'] = _items
        # override the default output from pydantic by calling `to_dict()` of updated_at
        if self.updated_at:
            _dict['updated_at'] = self.updated_at.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of DtoUserSearchRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "created_at": DtoDateRange.from_dict(obj.get("created_at")) if obj.get("created_at") is not None else None,
            "departments": obj.get("departments"),
            "email_pattern": obj.get("email_pattern"),
            "exclude_fields": obj.get("exclude_fields"),
            "filters": [DtoSearchFilter.from_dict(_item) for _item in obj.get("filters")] if obj.get("filters") is not None else None,
            "fullname_pattern": obj.get("fullname_pattern"),
            "include": obj.get("include"),
            "include_fields": obj.get("include_fields"),
            "is_active": obj.get("is_active"),
            "keyword": obj.get("keyword"),
            "last_login_range": DtoDateRange.from_dict(obj.get("last_login_range")) if obj.get("last_login_range") is not None else None,
            "page": obj.get("page"),
            "project_id": obj.get("project_id"),
            "project_ids": obj.get("project_ids"),
            "role_ids": obj.get("role_ids"),
            "size": obj.get("size"),
            "sort": [DtoSortOption.from_dict(_item) for _item in obj.get("sort")] if obj.get("sort") is not None else None,
            "status": obj.get("status"),
            "updated_at": DtoDateRange.from_dict(obj.get("updated_at")) if obj.get("updated_at") is not None else None,
            "user_id": obj.get("user_id"),
            "username_pattern": obj.get("username_pattern")
        })
        return _obj


